@@ -48,6 +48,11 @@ class Person(models.Model):
     )
     personnumber.sorting_name = "personnumber__int"
     name = models.CharField(_("Display name"), max_length=255, blank=True)
+    # this one is to solve a problem when sorting names from
+    # naturalperson and other types of person
+    default_sorting_name = models.CharField(
+        _("Default Sorting Name"), max_length=255, blank=True
+    )
     active = models.BooleanField(_("Active"), default=True)
     salutation_letter = models.CharField(
         _("Salutation Letter"),
@@ -162,6 +167,7 @@ class Person(models.Model):
                 )
             ):
                 self.primary_postal_address = active_postals[0]
+
         else:
             self.primary_postal_address = None
         if hasattr(self, "core_email_list"):
@@ -178,6 +184,8 @@ class Person(models.Model):
             self.personnumber = str(self.pk)
             super().save(update_fields=["personnumber"])
 
+        self.default_sorting_name = self.name
+
         # this signal needs to be sent manually in order to trigger the search-index update
         # Django does only send a signal for the child-model but our search-index only observes
         # this base model. It is only needed when creating for some reason...
@@ -288,6 +296,7 @@ class NaturalPerson(Person):
     def save(self, *args, **kwargs):
         if self.autogenerate_displayname:
             self.name = self.first_name + " " + self.last_name
+        self.default_sorting_name = self.last_name
         if self.decease_date:
             self.deceased = True
         self._type = (
