@@ -4,8 +4,9 @@ import bread
 import django
 import htmlgenerator as hg
 from bread import layout, menu
+from bread.layout.components.button import Button
 from bread.layout.components.forms import Form
-from bread.utils import reverse_model
+from bread.utils import Link, reverse_model
 from bread.views import EditView, ReadView, layoutasreadonly
 from django.apps import apps
 from django.conf import settings
@@ -18,7 +19,6 @@ from django.views.decorators.csrf import csrf_exempt
 
 from ... import models
 from ...layouts.editperson import legalperson, naturalperson, personassociation
-from ...layouts.editperson.common import contributions_tab
 from ...layouts.editperson.common.head import editperson_head
 from ...layouts.editperson.common.relationships_tab import relationshipstab
 
@@ -135,13 +135,20 @@ def editperson_tabs(base_data_tab, mailing_tab, request):
 
     from django.apps import apps
 
-    return [base_data_tab(request), relationshipstab(request), mailing_tab(request)] + (
-        [
+    if apps.is_installed("basxconnect.contributions"):
+        from ...layouts.editperson.common import contributions_tab
+
+        return [
+            base_data_tab(request),
+            relationshipstab(request),
+            mailing_tab(request),
             contributions_tab.contributions_tab(request),
         ]
-        if apps.is_installed("basxconnect.contributions")
-        else []
-    )
+    return [
+        base_data_tab(request),
+        relationshipstab(request),
+        mailing_tab(request),
+    ]
 
 
 @csrf_exempt
@@ -196,17 +203,38 @@ def confirm_delete_email(request, pk: int):
         request,
         import_string(settings.DEFAULT_PAGE_LAYOUT)(
             menu.main,
-            Form.wrap_with_form(
-                form,
-                hg.BaseElement(
-                    hg.H3(_("Delete email %s") % email.email),
-                    hg.If(
-                        enable_delete_mailer_contact_checkbox,
-                        bread.layout.form.FormField("delete_mailer_contact"),
-                        hg.BaseElement(),
+            hg.FORM(
+                Form(
+                    form,
+                    hg.BaseElement(
+                        hg.H3(_("Delete email %s") % email.email),
+                        hg.If(
+                            enable_delete_mailer_contact_checkbox,
+                            bread.layout.form.FormField("delete_mailer_contact"),
+                            hg.BaseElement(),
+                        ),
                     ),
+                    standalone=False,
+                ),
+                hg.DIV(
+                    Button(_("Save"), type="submit"),
+                    _class="bx--form-item",
+                    style="margin-top: 2rem; display: inline-block;",
+                ),
+                hg.DIV(
+                    Button.fromlink(
+                        Link(
+                            href=reverse_model(
+                                email.person, "read", kwargs={"pk": email.person.pk}
+                            ),
+                            label=_("Cancel"),
+                            iconname=None,
+                        ),
+                        buttontype="tertiary",
+                    ),
+                    _class="bx--form-item",
+                    style="margin-top: 2rem; display: inline-block; margin-left: 1rem;",
                 ),
-                submit_label=_("Confirm"),
             ),
         ),
     )
