@@ -191,6 +191,9 @@ class EditEmailAddressView(EditView):
             from basxconnect.mailer_integration import settings
 
             settings.MAILER.change_email_address(self.old_email, new_email)
+        else:
+            if hasattr(self.object, "subscription") and new_email != self.old_email:
+                self.object.subscription.delete()
         return ret
 
     def post(self, request, *args, **kwargs):
@@ -202,10 +205,15 @@ class EditEmailAddressView(EditView):
             is_primary = django.forms.BooleanField(
                 label=_("Use as primary email address"), required=False
             )
-            propagate_change_to_mailer = django.forms.BooleanField(
-                label=_("Propagate change of email address to external mailer"),
-                required=False,
-            )
+            propagate_change_to_mailer = django.forms.BooleanField(required=False)
+
+            if apps.is_installed("basxconnect.mailer_integration"):
+                import basxconnect.mailer_integration.settings as mailer_integration_settings
+
+                propagate_change_to_mailer.label = (
+                    _("Propagate change of email address to %s")
+                    % mailer_integration_settings.MAILER.name()
+                )
 
         return EditEmailForm
 
